@@ -12,9 +12,9 @@ from sklearn.preprocessing import StandardScaler, MinMaxScaler
 from sklearn.model_selection import GridSearchCV, train_test_split
 from sklearn.metrics import SCORERS
 from sklearn.exceptions import UndefinedMetricWarning
+from sklearn.feature_selection import SelectKBest, chi2
 from difflib import get_close_matches
 import numpy as np
-import inspect
 import os
 import pickle
 
@@ -32,17 +32,17 @@ class Model():
         an approximate representation of model name, for example: 'plsreg' will 
         initialiase an instance of the PLSRegression model.
     :parameters : dict (default = {})
-        parameters to use for building regression model, by default it set to {}, meaning
+        parameters to use for building regression model, by default it is set to {}, meaning
         all of the models' default parameters are used.
     :test_split : float (default = 0.2)
-        proportion of the test data to use for building model
+        proportion of the test data to use for building model.
 
     Methods
     -------
     get_model():
         build model using inputtted parameters.
     train_test_split(X, Y, scale = True, test_size = 0.2,random_state=None, shuffle=True):
-        get train test split of dataset.
+        get train-test split of dataset.
     fit():
         fit model.
     predict():
@@ -59,30 +59,29 @@ class Model():
     def __init__(self, algorithm, parameters={}, test_split=0.2):
 
         self.algorithm = algorithm
+        self.test_split = test_split
 
-        #if no parameters input to 
+        #if no parameters input, then set to {} meaning default parameters are used
         if (parameters == [] or parameters == ""):
             self.parameters = {}
         else:
             self.parameters = parameters
 
-        self.test_split = test_split
-
         #list of valid models available to use for this class
-        self.valid_models = ['PlsRegression','RandomForestRegressor','AdaBoostRegressor',\
-                            'BaggingRegressor','DecisionTreeRegressor', 'GBR', 
-                            'LinearRegression', 'Lasso', 'Ridge', 'SVR','SGD', 'KNeighborsRegressor', 'KNN']
+        self.valid_models = ['plsregression','randomforestregressor','adaboostregressor',\
+                            'baggingregressor','decisiontreeregressor', 'gbr', 'gradientboostingregressor', 
+                            'linearregression', 'lasso', 'ridge', 'svr', 'sgd', 'kneighborsregressor', 'knn']
 
         #get closest match of valid model from the input algorithm parameter value
-        model_matches = get_close_matches(self.algorithm.lower(),[item.lower() \
-            for item in self.valid_models], cutoff=0.4)
+        model_matches = get_close_matches(self.algorithm.lower().strip(),[item.lower().strip() \
+            for item in self.valid_models], cutoff=0.5)
 
         #if algorithm is a valid model then set it to self.algorithm, else raise error
         if model_matches!=[]:
             self.algorithm = model_matches[0]
         else:
-            raise ValueError('Input algorithm {} not found in available valid \
-                models {}.'.format(self.algorithm, self.valid_models))
+            raise ValueError('Input algorithm {} not found in available valid models {}.'.format(
+                    self.algorithm, self.valid_models))
 
         #create instance of algorithm object
         self.model = self.get_model()
@@ -96,14 +95,15 @@ class Model():
 
         Parameters
         ----------
-        :self (Model object) : instance of Model class.
+        :self (Model object) : 
+            instance of Model class.
 
         Returns
         -------
         :model : sklearn.model
             instantiated regression model with default or user-specified parameters.
         """
-        if self.algorithm.lower() == 'plsregression':
+        if self.algorithm.lower().strip() == 'plsregression':
 
             #get parameters of sklearn model and check that user inputted
             #  parameters are available in the model, only use those that are valid.
@@ -117,7 +117,7 @@ class Model():
             else:
                 model = PLSRegression()
 
-        elif self.algorithm.lower() == 'randomforestregressor':
+        elif self.algorithm.lower().strip() == 'randomforestregressor':
 
             model_params = set(dir(RandomForestRegressor()))
             parameters = [i for i in model_params if i in self.parameters]
@@ -127,7 +127,7 @@ class Model():
             else:
                 model = RandomForestRegressor()
 
-        elif self.algorithm.lower() == 'adaboostregressor':
+        elif self.algorithm.lower().strip() == 'adaboostregressor':
 
             model_params = set(dir(AdaBoostRegressor()))
             parameters = [i for i in model_params if i in self.parameters]
@@ -137,7 +137,7 @@ class Model():
             else:
                 model = AdaBoostRegressor()
 
-        elif self.algorithm.lower() == 'baggingregressor':
+        elif self.algorithm.lower().strip() == 'baggingregressor':
 
             model_params = set(dir(BaggingRegressor()))
             parameters = [i for i in model_params if i in self.parameters]
@@ -147,7 +147,7 @@ class Model():
             else:
                 model = BaggingRegressor()
 
-        elif self.algorithm.lower() == 'decisiontreeregressor':
+        elif self.algorithm.lower().strip() == 'decisiontreeregressor':
 
             model_params = set(dir(DecisionTreeRegressor()))
             parameters = [i for i in model_params if i in self.parameters]
@@ -157,7 +157,7 @@ class Model():
             else:
                 model = DecisionTreeRegressor()
 
-        elif self.algorithm.lower() == 'linearregression':
+        elif self.algorithm.lower().strip() == 'linearregression':
 
             model_params = set(dir(LinearRegression()))
             parameters = [i for i in model_params if i in self.parameters]
@@ -167,7 +167,7 @@ class Model():
             else:
                 model = LinearRegression()
 
-        elif self.algorithm.lower() == 'lasso':
+        elif self.algorithm.lower().strip() == 'lasso':
 
             model_params = set(dir(Lasso()))
             parameters = [i for i in model_params if i in self.parameters]
@@ -177,7 +177,7 @@ class Model():
             else:
                 model = Lasso()
 
-        elif self.algorithm.lower() == 'ridge':
+        elif self.algorithm.lower().strip() == 'ridge':
 
             model_params = set(dir(Ridge()))
             parameters = [i for i in model_params if i in self.parameters]
@@ -187,7 +187,7 @@ class Model():
             else:
                 model = Ridge()
 
-        elif self.algorithm.lower() == 'sgd':
+        elif self.algorithm.lower().strip() == 'sgd':
 
             model_params = set(dir(SGDRegressor()))
             parameters = [i for i in model_params if i in self.parameters]
@@ -197,8 +197,9 @@ class Model():
             else:
                 model = SGDRegressor()
 
-        elif self.algorithm.lower() == 'gbr':
-
+        elif self.algorithm.lower().strip() == 'gbr' or \
+            self.algorithm.lower().strip() == 'gradientboost' or \
+            self.algorithm.lower().strip() == 'gradientboostingregressor':
             model_params = set(dir(GradientBoostingRegressor()))
             parameters = [i for i in model_params if i in self.parameters]
 
@@ -207,7 +208,7 @@ class Model():
             else:
                 model = GradientBoostingRegressor()
 
-        elif self.algorithm.lower() == 'svr':
+        elif self.algorithm.lower().strip() == 'svr':
 
             model_params = set(dir(SVR()))
             parameters = [i for i in model_params if i in self.parameters]
@@ -217,8 +218,8 @@ class Model():
             else:
                 model = SVR()
 
-        elif self.algorithm.lower() == 'knn' or \
-           self.algorithm.lower() == 'kneighborsregressor':
+        elif self.algorithm.lower().strip() == 'knn' or \
+           self.algorithm.lower().strip() == 'kneighborsregressor':
 
             model_params = set(dir(KNeighborsRegressor()))
             parameters = [i for i in model_params if i in self.parameters]
@@ -228,8 +229,8 @@ class Model():
             else:
                 model = KNeighborsRegressor()
         else:
-            raise ValueError('Input Algorithm ({}) not found in available valid \
-                models'.format(self.algorithm, self.valid_models))
+            raise ValueError('Input Algorithm ({}) not found in available valid models'.
+                format(self.algorithm, self.valid_models))
 
         return model
 
@@ -266,8 +267,8 @@ class Model():
         """
         #validate that X and Y arrays are of the same size
         if (len(X)!=len(Y)):
-            raise ValueError('X and Y input parameters must be of the same length, \
-                X: {}, Y: {}'.format(len(X), len(Y)))
+            raise ValueError('X and Y input parameters must be of the same length, X: {}, Y: {}'.
+                format(len(X), len(Y)))
 
         #reshape input arrays to 2D arrays
         if (X.ndim!=2):
@@ -284,6 +285,7 @@ class Model():
         #scale training data X
         if scale:
             X = StandardScaler().fit_transform(X)
+            # X = MinMaxScaler().fit_transform(X)
 
         #split X and Y into training and test data
         X_train, X_test, Y_train, Y_test = train_test_split(X, Y,
@@ -349,7 +351,7 @@ class Model():
         except (IOError, OSError, pickle.PickleError, pickle.UnpicklingError):
             print("Error pickling model with path: {} .".format(save_path))
 
-    def hyperparameter_tuning(self, parameters, metric='r2', cv=5, n_jobs=None):
+    def hyperparameter_tuning(self, parameters={}, metric='r2', cv=5, n_jobs=None):
         """
         Hyperparamter tuning of model to find its optimal arrangment of parameters
         using a Grid Search.
@@ -358,7 +360,7 @@ class Model():
         ----------
         :self : (Model object)
             instance of Model class.
-        :parameters : dict
+        :parameters : dict (default = {})
             dictionary of parameter names and their values.
         :metric : str (default = r2)
             scoring metric used to evaluate the performance of the cross-validated
@@ -370,13 +372,11 @@ class Model():
 
         Returns
         -------
-        metrics_df: pd.DataFrame
-            dataframe of best results and the associated parameters from the
-            hyperparameter tuning process.
+        None
         """
         #input parameters parameter must be a dict, if not raise error
         if not isinstance(parameters, dict):
-            raise TypeError('Parameters argument must be of type dict.')
+            raise TypeError('Parameters argument must be of type dict, not of type {}.'.format(type(parameters)))
 
         #input metric must be in available scoring metrics, if not raise error
         if metric not in sorted(SCORERS.keys()):
@@ -396,7 +396,7 @@ class Model():
 
         #grid search of hyperparameter space for model
         model_copy = self.copy()
-        grid_search = GridSearchCV(estimator=model_copy, param_grid=parameters,\
+        grid_search = GridSearchCV(estimator=model_copy, param_grid=parameters, \
             cv=cv, scoring=metric, n_jobs=n_jobs, verbose=2, error_score=0)
 
         #fit X and Y to best model found in grid search
@@ -433,7 +433,7 @@ class Model():
         print('# RPD {}'.format(eval.rpd))
         print('# Variance {}\n'.format(eval.explained_var))
         print('###############################################################')
-
+        
     def copy(self):
         """
         Make a copy of the sklearn model stored in self.model instance variable.
@@ -467,6 +467,40 @@ class Model():
         """
         return (self.model_fit != None)
 
+    def feature_selection(self, X, Y, method=""):
+        """
+        Feature selection/dimensionality reduction on dataset and models.
+        Return the best applicable features found using the technique selected
+        from method input parameter.
+
+        Parameters
+        ----------
+        :X : np.ndarray
+            training data.
+        :Y : np.ndarray
+            training data labels.
+        :method : str (default = "")
+            feature selection method to use.
+
+        Returns
+        -------
+        :X_new : np.ndarray
+            best found features from training data.
+        """
+        valid_feature_selection = []
+
+        #get closest valid feature selection method
+        feature_matches = get_close_matches(method.lower().strip(), [item.lower().strip() \
+            for item in valid_feature_selection], cutoff=0.5)
+
+        #apply feature selection method according to input parameter
+        if feature_matches == 'selectkbest':
+            X_new = SelectKBest(chi2, k=2).fit_transform(X, Y)
+
+        return X_new
+
+        # https://scikit-learn.org/stable/modules/feature_selection.html
+        
 ######################          Getters & Setters          ######################
 
     @property
@@ -529,7 +563,7 @@ class Model():
 
     def __str__(self):
         return "Model of type {} using {} parameters, model fit = {}".format(
-            type(self.model).__name__, self.parameters, self.modelFitted())
+            type(self.model).__name__, self.parameters, self.model_fitted())
 
     def __repr__(self):
         return type(self.model).__name__
